Contributing to the DirSearch Library
=====================================

Contributions are welcome... please fork and submit a pull request!

Coding Style
------------

`PEP-8`_ is to be followed **strictly**; however line lengths of up to 90 or
100 columns is OK if the purpose of the line is still cleanly conveyed.

.. _`PEP-8`: https://www.python.org/dev/peps/pep-0008/

